@@ -23,7 +23,7 @@
 #include "gtkshell.h"
 
 void
-gsh_widget_set_font(GtkWidget *widget, gchar *font)
+gsh_widget_set_font(GtkWidget *widget, const gchar *font)
 {
 	PangoFontDescription *font_desc;
 
