@@ -24,7 +24,7 @@
 #define GTKSHELL_FONT_H
 
 void
-     gsh_widget_set_font(GtkWidget *widget, gchar *font);
+     gsh_widget_set_font(GtkWidget *widget, const gchar *font);
 
 void
      gsh_widget_set_font_mono(GtkWidget *widget);
