@@ -23,24 +23,12 @@
 #ifndef LIBAR_STRING_H
 #define LIBAR_STRING_H
 
-gint
-     ar_asprintf(gchar **string, const gchar *format,...);
+/*@printflike@*/gint
+ar_asprintf(gchar **string, 
+	    const gchar *format,
+	    ...) __attribute__((format(printf,2,3)));
 
 char *
-     antiright_beautified_label(char *current_argument_string);
+antiright_beautified_label(char *current_argument_string);
 
-/* char*      */
-
-/*
- * antiright_insert_string(char *text, char *insertion, unsigned int
- * position);
- */
-/* char* */
-
-/*
- * antiright_delete_range(char *text, unsigned int start, unsigned int
- * end);
- */
-/* char* */
-/* ar_insert_txt(char* source, char* text, unsigned int position); */
 #endif
